@@ -1,4 +1,3 @@
-import resotolib.logger
 from attrs import define
 from typing import Optional, ClassVar
 from resotolib.graph import Graph
@@ -9,8 +8,6 @@ from resotolib.baseresources import (
     BaseNetwork,
 )
 
-log = resotolib.logger.getLogger("resoto." + __name__)
-
 
 @define(eq=False, slots=False)
 class OnpremLocation(BaseAccount):
